/*
    (C) SergeySoft 2023 z-print@bk.ru
    Разделяет отсканированные шитые на скобу спуски А3, в книгу а4 с правильным порядком страниц
*/    

if (app.viewerVersion < 10) {
    
    app.addMenuItem({ cName: "Re-spread book from Scan", cUser: "Re-spread book from Scan", cParent: "Tools", cExec:"splitAndReoder()", cEnable: "event.rc = (event.target != null);"});
    
} else {

    app.addToolButton({ cName: "Re-spread book from Scan", cLabel: "Re-spread book from Scan", cExec: "splitAndReoder()", cEnable: "event.rc = (event.target != null);"});   
}

const SPREADSIZE = 4; //  количество страниц в комплекте А3

splitAndReoder = app.trustedFunction(function() {

//  дублируем страницы

    if ((this.numPages % 2) == 1) {
        app.alert ("Error on Scan\nIt must contain EVEN page count");
        throw new Error("File Scan Error - non EVEN page count");
    }
    
    app.beginPriv();
    
    try {
        //  сохраним под новым именем
        var newName = this.path;
        var filename = newName.replace(/\.pdf/i,"_reodered.pdf"); // save a copy of original document

        this.saveAs(filename);

        // сдублируем страницы, чтобы потом сделать из них левые/правые страницы спуска
        var num = this.numPages; //  текущее количество страниц в файле

        app.thermometer.duration = num;
        app.thermometer.begin();

        for (var i = 0; i < num; i++) {
            
            app.thermometer.value =  i;
            app.thermometer.text = "Page: " + i.toString();
            
            if (app.thermometer.cancelled) break;
            
            k = i * 2;
            this.insertPages({ nPage: k, cPath:newName, nStart:i });
        }
        app.thermometer.end();


        //  сделаем левые/правые страницы
        var num2 = this.numPages; // текущее количество страниц в файле. Чтобы на каждом проходе не обращаться к this.numPages 
        
        app.thermometer.duration = num2;
        app.thermometer.begin();

        for (i = 0; i < num2; i += 2) {
                
            app.thermometer.value =  i;
            app.thermometer.text = "Define Left/Right Pages: " + i.toString();
            if(app.thermometer.cancelled) break;

            //  левые страницы (четные)
            var aRect = this.getPageBox("Media", i);
            var halfW = (aRect[2] - aRect[0]) / 2;
            aRect[2] = aRect[0] + halfW;
            this.setPageBoxes("Media", i, i, aRect)

            //  правые страницы (нечетные)
            var aRect = this.getPageBox("Media", i+1);
            var halfW = (aRect[2] - aRect[0]) / 2;
            aRect[0] = aRect[2] - halfW;
            this.setPageBoxes("Media", i + 1, i + 1, aRect)
        };
        app.thermometer.end();

        //  переставим в условном порядке страницы с малыми номерами
        var spreadCount = num2 / SPREADSIZE; //  количество двусторонних А3

        app.thermometer.duration = spreadCount;
        app.thermometer.begin();

        for (i = 0; i < spreadCount; i++) {

            app.thermometer.value =  i;
            app.thermometer.text = "Reordering spread: " + i.toString();
            if(app.thermometer.cancelled) break;
            
            //  переставляем первую страницу спуска как последнюю книги
            //  вставляем в конец файла (this.numPages - 1), 
            // c учетом номера спуска (i * 2 - т.к. в начале все время исчезают по 2 страницы в спуске)
            // и отступом 0 для последней страницы, 1 - для предпоследней
            this.movePage(i * 2 + 0, num2 - 1 - i * 2 - 0);
            //  переставляем последнюю (3) страницу спуска как предпоследнюю книги. 
            // 2 - т.к. нумерация изменилась прошлой итерации
            this.movePage(i * 2 + 2, num2 - 1 - i * 2 - 1);

        }
        app.thermometer.end();

        app.endPriv();
    }
    
    catch(e) {
        app.alert(e);
    };
    
})
